/**
 * NetXMS - open source network management system
 * Copyright (C) 2003-2022 Victor Kirhenshtein
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package org.netxms.nxmc.modules.logviewer.widgets.helpers;

import org.eclipse.jface.viewers.CellEditor;
import org.eclipse.jface.viewers.CheckboxCellEditor;
import org.eclipse.jface.viewers.ColumnViewer;
import org.eclipse.jface.viewers.EditingSupport;
import org.eclipse.swt.SWT;
import org.netxms.client.log.OrderingColumn;

/**
 * @author Victor
 *
 */
public class OrderingColumnEditingSupport extends EditingSupport
{
	private CellEditor editor;

	/**
	 * @param viewer
	 */
	public OrderingColumnEditingSupport(ColumnViewer viewer)
	{
		super(viewer);
		editor = new CheckboxCellEditor(null, SWT.CHECK | SWT.READ_ONLY);
	}

   /**
    * @see org.eclipse.jface.viewers.EditingSupport#canEdit(java.lang.Object)
    */
	@Override
	protected boolean canEdit(Object element)
	{
		return true;
	}

   /**
    * @see org.eclipse.jface.viewers.EditingSupport#getCellEditor(java.lang.Object)
    */
	@Override
	protected CellEditor getCellEditor(Object element)
	{
		return editor;
	}

	/**
	 * @see org.eclipse.jface.viewers.EditingSupport#getValue(java.lang.Object)
	 */
	@Override
	protected Object getValue(Object element)
	{
		return Boolean.valueOf(((OrderingColumn)element).isDescending());
	}

	/**
	 * @see org.eclipse.jface.viewers.EditingSupport#setValue(java.lang.Object, java.lang.Object)
	 */
	@Override
	protected void setValue(Object element, Object value)
	{
		((OrderingColumn)element).setDescending((Boolean)value);
		getViewer().update(element, null);
	}
}
